pub fn is_dumb() -> boolExpand description
A fast way to check if the application has a dumb terminal.
On Unix: TERM environment variable is not set or set to dumb.
On Windows: TERM environment variable is explicitly set to dumb.
Native windows terminals typically do not set the TERM environment variable.